diff --git a/source/video_transcoder/changelog.md b/source/video_transcoder/changelog.md
index 3ebd3ddec..47cec9ca8 100644
--- a/source/video_transcoder/changelog.md
+++ b/source/video_transcoder/changelog.md
@@ -1,4 +1,7 @@
+**0.1.6**
+- Fix bug causing files to be perpetually added to the task queue if mode is set to advanced, but the smart filters were previously applied
+
**0.1.5**
- Fix video scaling smart filter for videos that do not use a 16:9 aspect ratio
diff --git a/source/video_transcoder/info.json b/source/video_transcoder/info.json
index b2639b47c..c1ff6b318 100644
--- a/source/video_transcoder/info.json
+++ b/source/video_transcoder/info.json
@@ -12,5 +12,5 @@
"on_worker_process": 1
},
"tags": "video,ffmpeg",
- "version": "0.1.5"
+ "version": "0.1.6"
}
diff --git a/source/video_transcoder/lib/plugin_stream_mapper.py b/source/video_transcoder/lib/plugin_stream_mapper.py
index 904202adc..5798737f0 100644
--- a/source/video_transcoder/lib/plugin_stream_mapper.py
+++ b/source/video_transcoder/lib/plugin_stream_mapper.py
@@ -255,14 +255,15 @@ def test_stream_needs_processing(self, stream_info: dict):
if self.settings.get_setting('apply_smart_filters'):
# Video filters
if codec_type in ['video']:
- # Check if autocrop filter needs to be applied
- if self.settings.get_setting('autocrop_black_bars') and self.crop_value:
- return True
- # Check if scale filter needs to be applied
- if self.settings.get_setting('target_resolution') not in ['source']:
- vid_width, vid_height = self.scale_resolution(stream_info)
- if vid_width:
+ if self.settings.get_setting('mode') == 'standard':
+ # Check if autocrop filter needs to be applied (standard mode only)
+ if self.settings.get_setting('autocrop_black_bars') and self.crop_value:
return True
+ # Check if scale filter needs to be applied (standard mode only)
+ if self.settings.get_setting('target_resolution') not in ['source']:
+ vid_width, vid_height = self.scale_resolution(stream_info)
+ if vid_width:
+ return True
# Data/Attachment filters
if codec_type in ['data', 'attachment']:
# Enable removal of data and attachment streams